# internal modules
from termkeymonitor.rich import cli

if __name__ == "__main__":
    cli()
